CheckBoxWidgetStyle class

this is the checkbox widget style

Constructors

CheckBoxWidgetStyle({BorderSide? side, Color? activeColor, Color? checkColor})
constructor of the class

Properties

activeColor ↔ Color?
active color
getter/setter pair
checkColor ↔ Color?
check box color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
side ↔ BorderSide?
decoration
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited