CustomTableDropDownModel<T> class

this is the value and the option of the row field when the row field is a dropdown with a generic data type T

Constructors

CustomTableDropDownModel({int? id, required String label, T? otherData})
T type data constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int?
final
label → String
final
otherData → T?
only this label is required
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited